# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os

TEKTON_GROUP = 'tekton.dev'
TEKTON_VERSION = os.environ.get('TEKTON_VERSION', 'v1beta1')
TEKTON_API_VERSION = TEKTON_GROUP + '/' + TEKTON_VERSION

TEKTON_LOGLEVEL = os.environ.get('TEKTON_LOGLEVEL', 'INFO').upper()
